@@ -13,6 +13,7 @@ class Review(TypedDict):
     user_id: str
     biz_id: str
     biz_name: str
+    biz_address: str
     review_id: str
     review_date: str
 
@@ -22,6 +23,7 @@ class Review(TypedDict):
             user_id=user_id,
             biz_id=scraped_review.biz_id,
             biz_name=scraped_review.biz_name,
+            biz_address=scraped_review.biz_address,
             review_id=scraped_review.review_id,
             review_date=scraped_review.review_date,
         )
@@ -31,10 +33,7 @@ def get_urls(user_id) -> List[str]:
     url = get_user_details_reviews_self_url(user_id)
     first_user_biz_soup = fetch_soup(url)
     num_user_biz_pages = get_num_pages(first_user_biz_soup)
-    urls = map(
-        lambda i: get_user_details_reviews_self_url(user_id, i),
-        range(num_user_biz_pages),
-    )
+    urls = map(lambda i: get_user_details_reviews_self_url(user_id, i), range(num_user_biz_pages),)
     return list(urls)
 
 
