@@ -1,3 +1,6 @@
+from typing import List
+
+from yelp_fetcher.reviews import Review
 from yelp_lambda.common_types import JobType, LambdaMessage
 
 
@@ -27,19 +30,16 @@ class WorkerResponse(LambdaMessage):
 
 
 class ReviewsWorkerResult(WorkerResponse):
-    def __init__(self, user_id, biz_id, biz_name, review_id, review_date):
+    def __init__(self, user_id, reviews: List[Review]):
         super().__init__(JobType.REVIEWS.value)
         self.user_id = user_id
-        self.biz_id = biz_id
-        self.biz_name = biz_name
-        self.review_id = review_id
-        self.review_date = review_date
+        self.reviews = reviews
 
 
 class StatusesWorkerResult(WorkerResponse):
-    def __init__(self, user_id, biz_id, review_id, is_alive):
+    def __init__(self, user_id, biz_id, review_id, status):
         super().__init__(JobType.STATUSES.value)
         self.user_id = user_id
         self.biz_id = biz_id
         self.review_id = review_id
-        self.is_alive = is_alive
+        self.status = status
